@@ -173,7 +173,7 @@ works2df <- function(data, abstract = TRUE, verbose = TRUE) {
     issn_l = "issn_l",
     host_organization = "host_organization_name"
   )
-  inst_cols <- c("id", "display_name", "ror", "country_code", "type")
+  inst_cols <- c("id", "display_name", "ror", "country_code", "type", "lineage")
   empty_inst <- empty_list(inst_cols)
 
   n <- length(data)
@@ -214,6 +214,7 @@ works2df <- function(data, abstract = TRUE, verbose = TRUE) {
           inst_idx <- lengths(l_inst) > 0
           if (length(inst_idx) > 0 && any(inst_idx)) {
             first_inst <- l_inst[inst_idx][[1]]
+            first_inst$lineage <- paste(first_inst$lineage, collapse = ", ")
           } else {
             first_inst <- empty_inst
           }
@@ -314,7 +315,7 @@ authors2df <- function(data, verbose = TRUE) {
   pb <- oa_progress(n)
   list_df <- vector(mode = "list", length = n)
 
-  inst_cols <- c("id", "display_name", "ror", "country_code", "type")
+  inst_cols <- c("id", "display_name", "ror", "country_code", "type", "lineage")
   empty_inst <- empty_list(inst_cols)
 
   author_process <- tibble::tribble(
@@ -350,6 +351,9 @@ authors2df <- function(data, verbose = TRUE) {
       if (is.na(sub_affiliation[[1]])) {
         sub_affiliation <- empty_inst
       }
+      if (length(sub_affiliation$lineage) > 1) {
+        sub_affiliation$lineage <- paste(sub_affiliation$lineage, collapse = ", ")
+      }
       sub_affiliation <- prepend(sub_affiliation, "affiliation")
     }
     sub_affiliation <- replace_w_na(sub_affiliation)
@@ -360,8 +364,8 @@ authors2df <- function(data, verbose = TRUE) {
     "id", "display_name", "display_name_alternatives", "relevance_score",
     "ids", "orcid", "works_count", "cited_by_count", "counts_by_year",
     "affiliation_display_name", "affiliation_id", "affiliation_ror",
-    "affiliation_country_code", "affiliation_type", "x_concepts",
-    "works_api_url"
+    "affiliation_country_code", "affiliation_type", "affiliation_lineage",
+    "x_concepts", "works_api_url"
   )
 
   out_df <- rbind_oa_ls(list_df)
